==> MIDITrail-Ver.1.3.1-Windows_src.zip: MIDITrail/MIDITrail/MTDashboard.h <==
//******************************************************************************
//
// MIDITrail / MTDashboard
//
// _bV{[h`NX
//
// Copyright (C) 2010-2013 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

// MEMO:
// Ȗ^tԁ^e|^r[g^ߔԍ \B

#pragma once

#include <d3d9.h>
#include <d3dx9.h>
#include "SMIDILib.h"
#include "MTStaticCaption.h"
#include "MTDynamicCaption.h"

using namespace SMIDILib;


//******************************************************************************
// p[^`
//******************************************************************************
//tHgݒ
#define MTDASHBOARD_FONTNAME  _T("MS Gothic")
#define MTDASHBOARD_FONTSIZE  (40)

//JE^LvV
#define MTDASHBOARD_COUNTER_CHARS  _T("ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789:/% ")

//JE^LvVTCY
//   12345678901234567890123456789012345678901234567890123456789012345678901234  (74)
//  "TIME:00:00/00:00 BPM:000 BEAT:4/4 BAR:000/000 NOTES:00000/00000 SPEED:000%"
//  ]T݂80ɂĂ
#define MTDASHBOARD_COUNTER_SIZE  (80)

//gTCYisNZj
#define MTDASHBOARD_FRAMESIZE  (5.0f)

//ftHg\g嗦
#define MTDASHBOARD_DEFAULT_MAGRATE  (0.5f)


//******************************************************************************
// _bV{[h`NX
//******************************************************************************
class MTDashboard
{
public:

	//RXgN^^fXgN^
	MTDashboard(void);
	virtual ~MTDashboard(void);

	//
	int Create(LPDIRECT3DDEVICE9 pD3DDevice, const TCHAR* pSceneName, SMSeqData* pSeqData, HWND hWnd);

	//XV
	int Transform(LPDIRECT3DDEVICE9 pD3DDevice, D3DXVECTOR3 camVector);

	//`
	int Draw(LPDIRECT3DDEVICE9 pD3DDevice);

	//
	void Release();

	//toߎԂƑtԂ̓o^
	void SetPlayTimeSec(unsigned long playTimeSec);
	void SetTotalPlayTimeSec(unsigned long totalPlayTimeSec);

	//e|o^
	void SetTempoBPM(unsigned long bpm);

	//ߔԍƑSߐ̓o^
	void SetBarNo(unsigned long barNo);
	void SetBarNum(unsigned long barNum);

	//qLo^
	void SetBeat(unsigned long numerator, unsigned long denominator);

	//m[gONo^
	void SetNoteOn();

	//txo^
	void SetPlaySpeedRatio(unsigned long ratio);

	//Zbg
	void Reset();

	//m[go^
	void SetNotesCount(unsigned long notesCount);

	//tԎ擾
	unsigned long GetPlayTimeSec();

	//\ݒ
	void SetEnable(bool isEnable);

	//t@C\ݒ
	void SetEnableFileName(bool isEnable);

private:

	HWND m_hWnd;
	
	MTStaticCaption m_Title;
	MTStaticCaption m_FileName;
	
	MTDynamicCaption m_Counter;
	float m_PosCounterX;
	float m_PosCounterY;
	float m_CounterMag;

	unsigned long m_PlayTimeSec;
	unsigned long m_TotalPlayTimeSec;
	unsigned long m_TempoBPM;
	unsigned long m_BeatNumerator;
	unsigned long m_BeatDenominator;
	unsigned long m_BarNo;
	unsigned long m_BarNum;
	unsigned long m_NoteCount;
	unsigned long m_NoteNum;
	unsigned long m_PlaySpeedRatio;

	unsigned long m_TempoBPMOnStart;
	unsigned long m_BeatNumeratorOnStart;
	unsigned long m_BeatDenominatorOnStart;

	D3DXCOLOR m_CaptionColor;

	//\
	bool m_isEnable;
	bool m_isEnableFileName;

	int _GetCounterPos(float* pX, float* pY);
	int _GetCounterStr(TCHAR* pStr, unsigned long bufSize);
	int _LoadConfFile(const TCHAR* pSceneName);

};

==> MIDITrail-Ver.1.4.0-Windows_src.zip: MIDITrail/MIDITrail/MTDashboard.h <==
//******************************************************************************
//
// MIDITrail / MTDashboard
//
// _bV{[h`NX
//
// Copyright (C) 2010-2022 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

// MEMO:
// Ȗ^tԁ^e|^r[g^ߔԍ \B

#pragma once

#include <d3d9.h>
#include <d3dx9.h>
#include "SMIDILib.h"
#include "MTStaticCaption.h"
#include "MTDynamicCaption.h"

using namespace SMIDILib;


//******************************************************************************
// p[^`
//******************************************************************************
//tHgݒ
#define MTDASHBOARD_FONTNAME  L"MS Gothic"
#define MTDASHBOARD_FONTSIZE  (40)

//JE^LvV
#define MTDASHBOARD_COUNTER_CHARS  L"ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789:/% "

//JE^LvVTCY
//   12345678901234567890123456789012345678901234567890123456789012345678901234  (74)
//  "TIME:00:00/00:00 BPM:000 BEAT:4/4 BAR:000/000 NOTES:00000/00000 SPEED:000%"
//  ]T݂80ɂĂ
#define MTDASHBOARD_COUNTER_SIZE  (80)

//gTCYisNZj
#define MTDASHBOARD_FRAMESIZE  (5.0f)

//ftHg\g嗦
#define MTDASHBOARD_DEFAULT_MAGRATE  (0.5f)


//******************************************************************************
// _bV{[h`NX
//******************************************************************************
class MTDashboard
{
public:

	//RXgN^^fXgN^
	MTDashboard(void);
	virtual ~MTDashboard(void);

	//
	int Create(LPDIRECT3DDEVICE9 pD3DDevice, const TCHAR* pSceneName, SMSeqData* pSeqData, HWND hWnd);

	//XV
	int Transform(LPDIRECT3DDEVICE9 pD3DDevice, D3DXVECTOR3 camVector);

	//`
	int Draw(LPDIRECT3DDEVICE9 pD3DDevice);

	//
	void Release();

	//toߎԂƑtԂ̓o^
	void SetPlayTimeSec(unsigned long playTimeSec);
	void SetTotalPlayTimeSec(unsigned long totalPlayTimeSec);

	//e|o^
	void SetTempoBPM(unsigned long bpm);

	//ߔԍƑSߐ̓o^
	void SetBarNo(unsigned long barNo);
	void SetBarNum(unsigned long barNum);

	//qLo^
	void SetBeat(unsigned long numerator, unsigned long denominator);

	//m[gONo^
	void SetNoteOn();

	//txo^
	void SetPlaySpeedRatio(unsigned long ratio);

	//Zbg
	void Reset();

	//m[go^
	void SetNotesCount(unsigned long notesCount);

	//tԎ擾
	unsigned long GetPlayTimeSec();

	//\ݒ
	void SetEnable(bool isEnable);

	//t@C\ݒ
	void SetEnableFileName(bool isEnable);

private:

	HWND m_hWnd;
	
	MTStaticCaption m_Title;
	MTStaticCaption m_FileName;
	
	MTDynamicCaption m_Counter;
	float m_PosCounterX;
	float m_PosCounterY;
	float m_CounterMag;

	unsigned long m_PlayTimeSec;
	unsigned long m_TotalPlayTimeSec;
	unsigned long m_TempoBPM;
	unsigned long m_BeatNumerator;
	unsigned long m_BeatDenominator;
	unsigned long m_BarNo;
	unsigned long m_BarNum;
	unsigned long m_NoteCount;
	unsigned long m_NoteNum;
	unsigned long m_PlaySpeedRatio;

	unsigned long m_TempoBPMOnStart;
	unsigned long m_BeatNumeratorOnStart;
	unsigned long m_BeatDenominatorOnStart;

	D3DXCOLOR m_CaptionColor;

	//\
	bool m_isEnable;
	bool m_isEnableFileName;

	int _GetCounterPos(float* pX, float* pY);
	int _GetCounterStr(WCHAR* pStr, unsigned long bufSize);
	int _LoadConfFile(const TCHAR* pSceneName);

};
